==> nuxeo-theme-webengine-5.4.0-I20100916_0115-sources.jar: org/nuxeo/theme/webengine/fm/extensions/NXThemesPanelDirective.java <==
/*
 * (C) Copyright 2006-2009 Nuxeo SAS (http://nuxeo.com/) and contributors.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * Contributors:
 *     Jean-Marc Orliaguet, Chalmers
 *
 * $Id$
 */

package org.nuxeo.theme.webengine.fm.extensions;

import java.io.IOException;
import java.io.Writer;
import java.util.Map;

import org.nuxeo.ecm.webengine.WebEngine;
import org.nuxeo.ecm.webengine.model.WebContext;
import org.nuxeo.theme.html.ui.Panel;

import freemarker.core.Environment;
import freemarker.template.TemplateDirectiveBody;
import freemarker.template.TemplateDirectiveModel;
import freemarker.template.TemplateException;
import freemarker.template.TemplateModel;
import freemarker.template.TemplateModelException;

/**
 * @author <a href="mailto:jmo@chalmers.se">Jean-Marc Orliaguet</a>
 *
 */
public class NXThemesPanelDirective implements TemplateDirectiveModel {

    @SuppressWarnings("unchecked")
    public void execute(Environment env, Map params, TemplateModel[] loopVars,
            TemplateDirectiveBody body) throws TemplateException, IOException {

        if (loopVars.length != 0) {
            throw new TemplateModelException(
                    "This directive doesn't allow loop variables.");
        }
        if (body != null) {
            throw new TemplateModelException("Didn't expect a body");
        }

        Writer writer = env.getOut();
        WebContext context = WebEngine.getActiveContext();

        Map<String, String> attributes = Utils.getTemplateDirectiveParameters(params);
        String applicationPath = context.getRequest().getParameter(
                "org.nuxeo.theme.application.path");
        if (applicationPath == null) {
            applicationPath = context.getModulePath();
        }
        attributes.put("org.nuxeo.theme.application.path", applicationPath);
        
        String applicationName = context.getRequest().getParameter(
                "org.nuxeo.theme.application.name");
        if (applicationName == null) {
            applicationName = context.getModule().getName();
        }
        attributes.put("org.nuxeo.theme.application.name", applicationName);

        writer.write(Panel.render(attributes));
    }
}

==> nuxeo-theme-webengine-7.4-I20150819_0121-sources.jar: org/nuxeo/theme/webengine/fm/extensions/NXThemesPanelDirective.java <==
/*
 * (C) Copyright 2006-2009 Nuxeo SAS (http://nuxeo.com/) and contributors.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser General Public License
 * (LGPL) version 2.1 which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * Contributors:
 *     Jean-Marc Orliaguet, Chalmers
 *
 * $Id$
 */

package org.nuxeo.theme.webengine.fm.extensions;

import java.io.IOException;
import java.io.Writer;
import java.util.Map;

import org.nuxeo.ecm.webengine.WebEngine;
import org.nuxeo.ecm.webengine.model.WebContext;
import org.nuxeo.theme.html.ui.Panel;

import freemarker.core.Environment;
import freemarker.template.TemplateDirectiveBody;
import freemarker.template.TemplateDirectiveModel;
import freemarker.template.TemplateException;
import freemarker.template.TemplateModel;
import freemarker.template.TemplateModelException;

/**
 * @author <a href="mailto:jmo@chalmers.se">Jean-Marc Orliaguet</a>
 */
public class NXThemesPanelDirective implements TemplateDirectiveModel {

    @SuppressWarnings("unchecked")
    public void execute(Environment env, Map params, TemplateModel[] loopVars, TemplateDirectiveBody body)
            throws TemplateException, IOException {

        if (loopVars.length != 0) {
            throw new TemplateModelException("This directive doesn't allow loop variables.");
        }
        if (body != null) {
            throw new TemplateModelException("Didn't expect a body");
        }

        Writer writer = env.getOut();
        WebContext context = WebEngine.getActiveContext();

        Map<String, String> attributes = Utils.getTemplateDirectiveParameters(params);
        String applicationPath = context.getRequest().getParameter("org.nuxeo.theme.application.path");
        if (applicationPath == null) {
            applicationPath = context.getModulePath();
        }
        attributes.put("org.nuxeo.theme.application.path", applicationPath);

        String applicationName = context.getRequest().getParameter("org.nuxeo.theme.application.name");
        if (applicationName == null) {
            applicationName = context.getModule().getName();
        }
        attributes.put("org.nuxeo.theme.application.name", applicationName);

        writer.write(Panel.render(attributes));
    }
}
